decaylanguage.decay
===================

.. testsetup::

    from decaylanguage.modeling.amplitudechain import *
    from decaylanguage.modeling.goofit import *
    from decaylanguage.modeling.decay import *
    from decaylanguage.modeling.ampgentransform import *

decaylanguage.modeling.decay
-------------------------

.. automodule:: decaylanguage.modeling.decay
    :members:

decaylanguage.modeling.ampgentransform
-----------------------------------

.. automodule:: decaylanguage.modeling.ampgentransform
    :members:

decaylanguage.modeling.amplitudechain
----------------------------------

.. automodule:: decaylanguage.modeling.amplitudechain
    :members:

decaylanguage.modeling.goofit
--------------------------

.. automodule:: decaylanguage.modeling.goofit
    :members:
